@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Optional, Sequence, Any, NamedTuple
+from typing import Optional, Sequence, Any, NamedTuple, Mapping, Union, Tuple, Type
 
 import inflection
 from typeit import TypeConstructor, flags
@@ -18,3 +18,4 @@ camelized = TypeConstructor & flags.GlobalNameOverride(lambda x: inflection.came
 dasherized = TypeConstructor & flags.GlobalNameOverride(inflection.dasherize)
 underscored = TypeConstructor
 
+AttrOverrides = Mapping[Union[property, Tuple[Type, str]], str]
